//	Draw4DHelpHowView.swift
//
//	© 2023 by Jeff Weeks
//	See TermsOfUse.txt

import SwiftUI


let helpHowHeaderColor = Color(.displayP3, red: 0.00, green: 0.5, blue: 0.75, opacity: 1.0)

struct Draw4DHelpHowView: View {

	var body: some View {

		ScrollView {
			VStack(alignment: .leading, spacing: 12) {
				
				Text("Intro-what")
					.font(.title2)
					.foregroundColor(helpHowHeaderColor)
					.frame(maxWidth: .infinity, alignment: .center)
				
				Text("Intro-how")
					.font(.body)

				Draw4DHelpItem(
					icon: "Touch Modes/Add Points",
					what: "AddPoints-what",
					how: "AddPoints-how",
					note: nil)

				Draw4DHelpItem(
					icon: "Touch Modes/Add Edges",
					what: "AddEdges-what",
					how: "AddEdges-how",
					note: nil)

				Draw4DHelpItem(
					icon: "Touch Modes/Move Points",
					what: "MovePoints-what",
					how: "MovePoints-how",
					note: "MovePoints-note")

				Draw4DHelpItem(
					icon: "Touch Modes/Delete Points",
					what: "DeletePoints-what",
					how: "DeletePoints-how",
					note: nil)

				Draw4DHelpItem(
					icon: "Touch Modes/Delete Edges",
					what: "DeleteEdges-what",
					how: "DeleteEdges-how",
					note: nil)

				Draw4DHelpItem(
					icon: nil,
					what: "RotateScene-what",
					how: "RotateScene-how",
					note: nil)
			}
		}
		.padding(geometryGamesPanelPadding)
		//	preferredColorScheme() works in 4D Maze, but not in 4D Draw,
		//	possibly because when SwiftUI translates everyting to UIKit
		//	under the hood, it handles the "presentation" context differently.
		//	As a workaround, the info.plist file sets Appearance = Light,
		//	with the drawback that the Nav Bar is also light.
		.background(Color(UIColor.systemBackground))
		.preferredColorScheme(.light)
		.cornerRadius(geometryGamesCornerRadius)
		.frame(width: 320.0, height: 480.0)
	}
}

struct Draw4DHelpItem: View {
	
	let icon: String?
	let what: LocalizedStringKey
	let how: LocalizedStringKey
	let note: LocalizedStringKey?

	var body: some View {

		VStack(alignment: .leading) {

			Text(what)
				.font(.title3)
				.italic()
				.foregroundColor(helpHowHeaderColor)

			Spacer()
				.frame(height: 4.0)
			
			VStack(alignment: .leading, spacing: 4.0) {
				
				HStack {

					if let theIconName = icon {
						Image(theIconName)
							.padding(8.0)
							.background(.gray)
							.cornerRadius(8.0)
							.padding(EdgeInsets(top: 0.0, leading: 16.0, bottom: 0.0, trailing: 16.0))
					}

					Text(how)
						.font(.body)
				}

				if let theNoteText = note {

					HStack {

						//	Insert a "hidden" copy of the icon,
						//	to provide the correct spacing.
						if let theIconName = icon {
							Image(theIconName)
								.padding(EdgeInsets(top: 0.0, leading: 16.0, bottom: 0.0, trailing: 16.0))
								.hidden()
						}

						Text(theNoteText)
						 .font(.footnote)
						 .foregroundColor(.gray)
					}
				}
			}
			//	Any non-zero top padding (even 0.00001)
			//	causes SwiftUI to insert way too much space.
			//	So let's leave the top padding at 0.0,
			//	and use a Spacer (above) instead.
			.padding(EdgeInsets(top: 0.0, leading: 8.0, bottom: 0.0, trailing: 0.0))
		}
		.lineLimit(nil)
//		.fixedSize(horizontal: false, vertical: true)	//	workaround for bug described in CrystalFlightHelpItem
	}
}
