//	GeometryGamesUtilities.swift
//
//	© 2023 by Jeff Weeks
//	See TermsOfUse.txt

import SwiftUI
import simd


//	Assuming a constant frame rate, and let gFramePeriod
//	be the time from the start of one frame to the start of the next.
//
let gFramePeriod: CFTimeInterval = 1.0 / CFTimeInterval(UIScreen.main.maximumFramesPerSecond)	//	in seconds

let gQuaternionIdentity = simd_quatd(real: 1.0, imag: .zero)

let gRunningOnMacFlag = ProcessInfo.processInfo.isiOSAppOnMac


func mainScreenSupportsP3() -> Bool {

#if targetEnvironment(simulator)

//	Even when running macOS 11.2.3 on an M1 MacBook Air (2020),
//	the Simulator renders on in non-extended sRGB.
//	I can check this again with future versions of macOS.

	//	The iOS simulator will claim to support Display P3
	//	whenever the simulated device does, but in reality
	//	it renders only in non-extended sRGB.
	return false
#else
	return UIScreen.main.traitCollection.displayGamut == UIDisplayGamut.P3
#endif
}


func convertDouble3x3toFloat3x3(
	_ m: simd_double3x3
) -> simd_float3x3 {

	let theFloat3x3 = simd_float3x3(
		SIMD3<Float>(m[0]),
		SIMD3<Float>(m[1]),
		SIMD3<Float>(m[2])
	)

	return theFloat3x3
}

func convertDouble4x4toFloat4x4(
	_ m: simd_double4x4
) -> simd_float4x4 {

	let theFloat4x4 = simd_float4x4(
		SIMD4<Float>(m[0]),
		SIMD4<Float>(m[1]),
		SIMD4<Float>(m[2]),
		SIMD4<Float>(m[3])
	)

	return theFloat4x4
}

func convertDouble4x3toFloat4x3(
	_ m: simd_double4x3
) -> simd_float4x3 {

	let theFloat4x3 = simd_float4x3(
		SIMD3<Float>(m[0]),
		SIMD3<Float>(m[1]),
		SIMD3<Float>(m[2]),
		SIMD3<Float>(m[3])
	)

	return theFloat4x3
}

func matrix4x4ExtendingMatrix3x3(
	_ m: simd_double3x3
) -> simd_double4x4 {

	let theMatrix4x4 = simd_double4x4(
		SIMD4<Double>(m[0][0], m[0][1], m[0][2], 0.0),
		SIMD4<Double>(m[1][0], m[1][1], m[1][2], 0.0),
		SIMD4<Double>(m[2][0], m[2][1], m[2][2], 0.0),
		SIMD4<Double>(  0.0,     0.0,     0.0,   1.0)
	)
	
	return theMatrix4x4
}


func PrintDocumentDirectoryPathToConsole() {
	
	let thePaths = FileManager.default.urls(for: .documentDirectory, in: .userDomainMask)
	let theDocumentDirectoryPath = thePaths[0]
	print("Document directory: " + theDocumentDirectoryPath.absoluteString)
}
